==> pytgm-4.0.6.tar.gz: pytgm-4.0.6/LICENCE.md <==
# Bspace License
Version 1.1.0
Copyright (c) 2024 Tokyn Blast

## Definitions

- **"Program"** refers to pyTGM and any of its variations
- **"Original Author"** refers to Tokyn Blast
- **"Developer"** refers to any person or organization working with the Program
- **"Variation"** refers to any modified version of the Program as defined in Section 4

## 1. Grant of Rights

Subject to the terms of this License, you are granted the rights to:
1. Use the Program for any purpose
2. Modify the Program
3. Distribute the Program or any Variations

## 2. Commercial Use

Commercial use is permitted only with explicit written permission from the Developer, unless otherwise stated.

## 3. Conditions

All Variations must:
1. Remain open source
2. Use this same license
3. Clearly attribute the Original Author
4. Include prominent links to the original Program

## 4. Definition of Variations

A Variation includes, but is not limited to:
1. Complete or partial copies of the Program
2. Derivative works based on pyTGM
3. Works incorporating any portion of the source code
4. Modified versions of the source code

## 5. Attribution Requirements

When publishing a Variation, the following must be prominently displayed on the download page:

```
This is a variation of the python library pyTGM (Licensed under Bspace 1.1.0) by Tokyn Blast
To get pyTGM: https://github.com/TokynBlast/pyTGM
```

## 6. Derivative Works

Projects created using this library as a dependency are not required to be open source.

## 7. Liability

The Original Author is not liable for any Variations or modifications made by other Developers.<br>
This includes harm to either self, others, properties, or other damagable objects.<br>

## 8. Profit and Monetization

Developers may monetize their Variations unless explicitly prohibited by the Original Author through any means (verbal, digital, physical, or otherwise).

## 9. License Modifications

This license may not be modified. All Variations must use this license in its exact form.

## 10. Void of Contract

This contract will only become void if and only if all copies of pyTGM, derivatives, and modifications that use this licence are destroyed on your device.<br>
This includes any accounts you use on any device, public or private accounts.

## 11. Death of Tokyn Blast

When Tokyn Blast dies, pyTGM will either go to a sucessor, or if a sucessor is not chosen within a year, pyTGM will be donated to one of the following:
1. mozilla
2. NDSU
3. A family member of Tokyn Blast
4. Foxyville
5. A non-profit organiztion
6. An agreed location of Tokyn Blast family
7. The pyTGM community (If any)

The family member who has the most experience in programming will have the most say.<br>
Then the most relevance in tech.<br>
Then, everybody else.
The pyTGM community will have %15 say in what happens, no matter who pyTGM goes to.

This portion may NOT be removed, unless<br>
Chosen to do so by
- Tokyn Blast
- The chosen sucessor
- Family after the death of Tokyn Blast

Or, if it is donated to the community, this part will be deleted.

==> pytgm-4.1.2.tar.gz: pytgm-4.1.2/LICENCE.md <==
# Bspace License
Version 1.1.2
Copyright (c) 2025 Tokyn Blast

## Definitions

- **"Program"** refers to pyTGM and any of its variations
- **"Original Author"** refers to Tokyn Blast
- **"Developer"** refers to any person or organization working with the Program
- **"Variation"** refers to any modified version of the Program as defined in Section 4

## 1. Grant of Rights

Subject to the terms of this License, you are granted the rights to:
1. Use the Program for any purpose
2. Modify the Program
3. Distribute the Program or any Variations

## 2. Commercial Use

Commercial use is permitted for pyTGM at any time, unless otherwsie stated.<br>

## 3. Conditions

All Variations must:
1. Remain open source
2. Use this same license
3. Clearly attribute the Original Author
4. Include prominent links to the original Program

## 4. Definition of Variations

A Variation includes, but is not limited to:
1. Complete or partial copies of the Program
2. Derivative works based on pyTGM
3. Works incorporating any portion of the source code
4. Modified versions of the source code

## 5. Attribution Requirements

When publishing a Variation, the following must be prominently displayed on the download page:

```
This is a variation of the python library pyTGM (Licensed under Bspace 1.1.0) by Tokyn Blast
To get pyTGM: https://github.com/TokynBlast/pyTGM
```

## 6. Derivative Works

Projects created using this library as a dependency are not required to be open source.
They are also subject to this license, unless stated otherwise.

## 7. Liability

The Original Author is not liable for any Variations or modifications made by other Developers.<br>
This includes harm to either self, others, properties, or other damagable objects.<br>

## 8. Profit and Monetization

Developers may monetize their Variations unless explicitly prohibited by the Original Author through any means (verbal, digital, physical, or otherwise).

## 9. License Modifications

This license may not be modified. All Variations must use this license in its exact form.

## 10. Void of Contract

This contract will only become void if and only if all copies of pyTGM, derivatives, and modifications that use this licence are destroyed on your device.<br>
This includes any accounts you use on any device, public or private accounts.

## 11. Death of Tokyn Blast

When Tokyn Blast dies, pyTGM will either go to a sucessor, or if a sucessor is not chosen within a year, pyTGM will be donated to one of the following:
1. mozilla
2. NDSU
3. A family member of Tokyn Blast
4. Foxyville
5. A non-profit organiztion
6. An agreed location of Tokyn Blast family
7. The pyTGM community (If any)

The family member who has the most experience in programming will have the most say.<br>
Then the most relevance in tech.<br>
Then, everybody else.
The pyTGM community will have %15 say in what happens, no matter who pyTGM goes to.

This portion may NOT be removed, unless<br>
Chosen to do so by
- Tokyn Blast
- The chosen sucessor
- Family after the death of Tokyn Blast

Or, if it is donated to the community, this part will be deleted.
